@@ -6,7 +6,7 @@ from sqlalchemy import select
 from sqlalchemy.orm import Mapped, mapped_column
 
 from hdx.database.no_timezone import Base
-from hdx.database.views import view
+from hdx.database.views import build_views
 
 
 class DBTestDate(Base):
@@ -25,8 +25,10 @@ class DBTestDate(Base):
         return f"<Test date={str(self.test_date)}>"
 
 
-date_view = view(
-    name="date_view",
-    metadata=Base.metadata,
-    selectable=select(*DBTestDate.__table__.columns),
-)
+date_view_params = {
+    "name": "date_view",
+    "metadata": Base.metadata,
+    "selectable": select(*DBTestDate.__table__.columns),
+}
+
+date_view = build_views([date_view_params])[0]
